SSL.Protocol.HandshakeFramer (ex_ssl v0.16.7)

Copy Markdown View Source

Frames complete TLS handshake messages from an arbitrarily chunked byte stream.

Incomplete data is retained as an opaque chunk accumulator so repeated small feeds do not rebuild the entire buffered message.

Summary

Types

t()

@opaque t()

Functions

buffered_bytes(buffer)

@spec buffered_bytes(t() | binary()) :: binary()

buffered_size(buffer)

@spec buffered_size(t() | binary()) :: non_neg_integer()

feed(buffer, bytes, opts \\ [])

@spec feed(t() | binary(), binary(), keyword()) ::
  {:ok, [binary()], t()} | {:error, term()}

new()

@spec new() :: t()