Frames complete TLS handshake messages from an arbitrarily chunked byte stream.
Incomplete data is retained as an opaque chunk accumulator so repeated small feeds do not rebuild the entire buffered message.
Frames complete TLS handshake messages from an arbitrarily chunked byte stream.
Incomplete data is retained as an opaque chunk accumulator so repeated small feeds do not rebuild the entire buffered message.