Frames complete TLS records from an arbitrarily chunked byte stream.
Incomplete data is retained as an opaque chunk accumulator so repeated small feeds do not rebuild the entire buffered record.
Frames complete TLS records from an arbitrarily chunked byte stream.
Incomplete data is retained as an opaque chunk accumulator so repeated small feeds do not rebuild the entire buffered record.