Immutable storage and hashing for exact encoded TLS handshake messages.
Messages are retained as reversed iodata chunks so appending does not flatten or repeatedly copy the transcript.
Summary
Types
@type hash() :: :sha256 | :sha384
@type t() :: %SSL.Protocol.Transcript{ hash: hash(), length: non_neg_integer(), messages: [iodata()] }
Functions
@spec apply_hello_retry_request_rewrite(t()) :: %SSL.Protocol.Transcript{ hash: :sha256 | :sha384, length: non_neg_integer(), messages: [<<_::32, _::_*8>>, ...] }
@spec new(hash()) :: %SSL.Protocol.Transcript{ hash: :sha256 | :sha384, length: 0, messages: [] }